summaryrefslogtreecommitdiff
path: root/src/lib/config.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2014-07-13 21:56:17 +0100
committerCarl Hetherington <cth@carlh.net>2014-07-13 21:56:17 +0100
commitdbd26fada835a44d7547007fc44273b2119f3e35 (patch)
tree2693d80bc9a65c767f876e623a8db26a9c12fe27 /src/lib/config.h
parent3ddd928233130695d7f4eeee47a71409d8c04de7 (diff)
Rename SoundProcessor -> CinemaSoundProcessor.
Diffstat (limited to 'src/lib/config.h')
-rw-r--r--src/lib/config.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/lib/config.h b/src/lib/config.h
index d9f104c7d..2bc07b683 100644
--- a/src/lib/config.h
+++ b/src/lib/config.h
@@ -35,7 +35,7 @@
class ServerDescription;
class Scaler;
class Filter;
-class SoundProcessor;
+class CinemaSoundProcessor;
class DCPContentType;
class Ratio;
class Cinema;
@@ -103,9 +103,9 @@ public:
return _tms_password;
}
- /** @return The sound processor that we are using */
- SoundProcessor const * sound_processor () const {
- return _sound_processor;
+ /** @return The cinema sound processor that we are using */
+ CinemaSoundProcessor const * cinema_sound_processor () const {
+ return _cinema_sound_processor;
}
std::list<boost::shared_ptr<Cinema> > cinemas () const {
@@ -394,8 +394,8 @@ private:
std::string _tms_user;
/** Password to log into the TMS with */
std::string _tms_password;
- /** Our sound processor */
- SoundProcessor const * _sound_processor;
+ /** Our cinema sound processor */
+ CinemaSoundProcessor const * _cinema_sound_processor;
std::list<int> _allowed_dcp_frame_rates;
/** Allow any video frame rate for the DCP; if true, overrides _allowed_dcp_frame_rates */
bool _allow_any_dcp_frame_rate;